<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=id
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Aktifkan plugin',
	'aide_non_disponible' => 'Bagian dari bantuan online ini belum tersedia dalam bahasa pengantar yang digunakan sekarang.',
	'auteur' => 'Penulis:',
	'avis_acces_interdit' => 'Dilarang mengakses.',
	'avis_article_modifie' => 'Perhatian, @nom_auteur_modif@ telah mengedit artikel ini @date_diff@ menit yang lalu',
	'avis_aucun_resultat' => 'Tidak ditemukan hasil apa-apa.',
	'avis_chemin_invalide_1' => 'Path yang telah anda pilih',
	'avis_chemin_invalide_2' => 'sepertinya tidak benar. Silakan kembali ke halaman sebelumnya dan verifikasi informasi yang diberikan.',
	'avis_connexion_echec_1' => 'Koneksi ke server SQL gagal.', # MODIF
	'avis_connexion_echec_2' => 'Kembali ke halaman sebelumnya, dan verifikasi informasi yang anda telah berikan.',
	'avis_connexion_echec_3' => '<b>Catatan:</b> Pada sejumlah server, anda harus <b>memohon</b> aktivasi akses ke database SQL sebelum anda dapat menggunakannya. Jika anda tidak berhasil mengakses database anda, pastikan anda telah mengajukan permohonan ini.', # MODIF
	'avis_connexion_ldap_echec_1' => 'Koneksi ke server LDAP gagal.',
	'avis_connexion_ldap_echec_2' => 'Kembali ke halaman sebelumnya, dan verifikasi informasi yang anda telah berikan.',
	'avis_connexion_ldap_echec_3' => 'Alternatif lainnya, jangan gunakan dukungan LDAP untuk mengimpor pengguna.',
	'avis_deplacement_rubrique' => 'Peringatan! Bagian ini mengandung @contient_breves@ berita@scb@: jika anda memindahkannya, silakan cek kotak ini untuk konfirmasi.',
	'avis_erreur_connexion_mysql' => 'Kesalahan koneksi SQL',
	'avis_espace_interdit' => '<b>Area terlarang</b><p>SPIP telah diinstal.',
	'avis_lecture_noms_bases_1' => 'Sistem instalasi tidak dapat membaca nama-nama database yang terinstal.',
	'avis_lecture_noms_bases_2' => 'Bisa jadi tidak ada database yang tersedia, atau fitur yang mengizinkan penampilan daftar database dinonaktifkan
  dengan alasan keamanan (yang sering ditemui pada banyak hosting).',
	'avis_lecture_noms_bases_3' => 'Jika alternatif kedua benar, sangat mungkin sebuah database dinamai sama dengan log masuk anda:',
	'avis_non_acces_page' => 'Anda tidak memiliki akses ke halaman ini.',
	'avis_operation_echec' => 'Operasi gagal.',
	'avis_operation_impossible' => 'Operasi tidak mungkin dijalankn',
	'avis_suppression_base' => 'PERINGATAN, data yang dihapus tidak dapat dikembalikan lagi',

	// B
	'bouton_acces_ldap' => 'Tambah sebuah akses ke LDAP >>',
	'bouton_ajouter' => 'Tambah',
	'bouton_annuler' => 'Batal',
	'bouton_demande_publication' => 'Permohonan publikasi artikel ini',
	'bouton_desactive_tout' => 'Non aktifkan semua',
	'bouton_effacer_tout' => 'Hapus SEMUA',
	'bouton_envoyer_message' => 'Pesan terakhir: kirim',
	'bouton_modifier' => 'Modifikasi',
	'bouton_radio_afficher' => 'Tampilkan',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Muncul di daftar editor-editor yang terkoneksi',
	'bouton_radio_envoi_annonces_adresse' => 'Kirim pengumuman ke alamat:',
	'bouton_radio_envoi_liste_nouveautes' => 'Kirim daftar berita terbaru',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Jangan muncul di daftar editor-editor yang terkoneksi',
	'bouton_radio_non_envoi_annonces_editoriales' => 'Jangan kirim pengumuman editorial apapun juga',
	'bouton_redirection' => 'MENGALIHKAN TUJUAN	',
	'bouton_relancer_installation' => 'Menjalankan instalasi kembali',
	'bouton_suivant' => 'Selanjutnya',
	'bouton_tenter_recuperation' => 'Usaha perbaikan',
	'bouton_test_proxy' => 'Tes proxy',
	'bouton_vider_cache' => 'Kosongkan cache',

	// C
	'cache_modifiable_webmestre' => 'Parameter ini dapat dimodifikasi oleh webmaster.',
	'calendrier_synchro' => 'Jika anda menggunakan aplikasi kalender yang kompatibel dengan <b>iCal</b>, anda dapat mensinkronisasikannya dengan informasi situs ini.',
	'connexion_ldap' => 'Koneksi:',

	// D
	'date_mot_heures' => 'H',

	// E
	'email' => 'e-mail',
	'email_2' => 'e-mail:',
	'entree_adresse_annuaire' => 'Alamat direktori',
	'entree_adresse_email' => 'Alamat e-mail anda',
	'entree_base_donnee_1' => 'Alamat database',
	'entree_base_donnee_2' => '(Sering kali, alamat ini sesuai dengan alamat situs anda, kadangkala ia berkaitan dengan nama «localhost», dan bisa juga dibiarkan tidak terisi sama sekali.)',
	'entree_biographie' => 'Biografi singkat dalam beberapa kata.',
	'entree_chemin_acces' => '<b>Isi</B> path:',
	'entree_cle_pgp' => 'Kunci PGP anda',
	'entree_contenu_rubrique' => '(Isi bagian dalam beberapa kata.)',
	'entree_identifiants_connexion' => 'Pengidentifikasi koneksi anda...',
	'entree_informations_connexion_ldap' => 'Silakan isi formulir ini dengan informasi koneksi LDAP. Anda akan memperoleh informasi yang diminta melalui administrator jaringan atau sistem anda.',
	'entree_infos_perso' => 'Siapa anda?',
	'entree_interieur_rubrique' => 'Dalam bagian:',
	'entree_liens_sites' => '<b>Tautan web</B> (referensi, situs yang dapat dikunjungi...)',
	'entree_login' => 'Log masuk anda',
	'entree_login_connexion_1' => 'Log masuk koneksi',
	'entree_login_connexion_2' => '(Kadang kala sesuai dengan log masuk akses FTP anda dan bisa jadi juga dibiarkan tidak terisi)',
	'entree_mot_passe' => 'Kata sandi anda',
	'entree_mot_passe_1' => 'Kata sandi koneksi',
	'entree_mot_passe_2' => '(Kadang kala sesuai dengan kata sandi akses FTP anda dan bisa jadi juga dibiarkan tidak terisi)',
	'entree_nom_fichier' => 'Silakan isi nama berkas @texte_compresse@:',
	'entree_nom_pseudo' => 'Nama atau alias anda',
	'entree_nom_pseudo_1' => '(Nama atau alias anda)',
	'entree_nom_site' => 'Nama situs anda',
	'entree_nouveau_passe' => 'Kata sandi baru',
	'entree_passe_ldap' => 'Kata sandi',
	'entree_port_annuaire' => 'Nomor port direktori',
	'entree_signature' => 'Tanda tangan',
	'entree_titre_obligatoire' => '<b>Judul</b> [Dibutuhkan]<br />',
	'entree_url' => 'URL situs anda',
	'erreur_plugin_fichier_absent' => 'Berkas hilang',
	'erreur_plugin_fichier_def_absent' => 'Berkas definisi hilang',
	'erreur_plugin_nom_fonction_interdit' => 'Nama fungsi yang dilarang',
	'erreur_plugin_nom_manquant' => 'Nama plugin yang hilang',
	'erreur_plugin_prefix_manquant' => 'Nama plugin tidak terdefinisi',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; hilang dalam berkas definisi',
	'erreur_plugin_version_manquant' => 'Versi plugin yang hilang',

	// I
	'ical_info1' => 'Halaman ini memberikan sejumlah metode untuk mengetahui dan berhubungan dengan aktivitas situs ini.',
	'ical_info2' => 'Untuk informasi lebih lanjut, jangan segan-segan untuk mengunjungi <a href="@spipnet@">dokumentasi SPIP</a>.', # MODIF
	'ical_info_calendrier' => 'Dua kalender berada di tangan anda siap untuk dipakai. Yang pertama adalah peta situs yang menampilkan semua artikel yang dipublikasi. Yang kedua berisikan pengumuman editorial sekaligus pesan-pesan pribadi terbaru anda: semuanya dapat disimpan berkat kunci pribadi yang bisa anda modifikasi setiap saat dengan jalan memperbaharui kata sandi.',
	'ical_methode_http' => 'Mengunduh',
	'ical_methode_webcal' => 'Sinkronisasi (webcal://)', # MODIF
	'ical_texte_js' => 'Sebuah kode javascript mengizinkan anda untuk menampilkan secara mudah dan di setiap situs yang anda miliki, semua artikel terbaru yang dipublikasikan di situs ini.',
	'ical_texte_prive' => 'Kalender ini, yang sifatnya pribadi sekali, menginformasikan anda seluruh aktivitas editorial pribadi situs ini (tugas-tugas, janji-janji pribadi, artikel-artikel dan berita-berita yang dikirimkan...).',
	'ical_texte_public' => 'Kalender ini memperbolehkan anda mengikuti aktivitas umum situs ini (artikel-artikel dan berita-berita yang dipublikasi).',
	'ical_texte_rss' => 'Anda dapat mensindikasi berita-berita terbaru situs ini melalui pembaca berkas XML/RSS (Rich Site Summary) apa saja. Ini juga merupakan format yang mengizinkan SPIP untuk membaca berita-berita terbaru yang dipublikasi oleh situs-situs lainnya menggunakan format yang kompatibel (situs-situs tersindikasi).',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Daftar Surat',
	'ical_titre_rss' => 'Berkas-berkas sindikasi',
	'icone_activer_cookie' => 'Meletakkan sebuah cookie',
	'icone_admin_plugin' => 'Mengelola plugin',
	'icone_afficher_auteurs' => 'Tampilkan penulis',
	'icone_afficher_visiteurs' => 'Tampilkan pengunjung',
	'icone_arret_discussion' => 'Berhenti berpartisipasi dalam diskusi ini',
	'icone_calendrier' => 'Kalender',
	'icone_creer_auteur' => 'Buat seorang penulis baru dan asosiasikan dia dengan artikel ini',
	'icone_creer_mot_cle' => 'Buat sebuah kata kunci baru dan tautkan ia ke artikel ini',
	'icone_creer_rubrique_2' => 'Buat sebuah bagian baru',
	'icone_modifier_article' => 'Modifikasi artikel ini',
	'icone_modifier_rubrique' => 'Modifikasi bagian ini',
	'icone_retour' => 'Kembali',
	'icone_retour_article' => 'Kembali ke artikel',
	'icone_supprimer_cookie' => 'Hapus cookie',
	'icone_supprimer_rubrique' => 'Hapus bagian ini',
	'icone_supprimer_signature' => 'Hapus tanda tangan ini',
	'icone_valider_signature' => 'Validasi tanda tangan ini',
	'image_administrer_rubrique' => 'Anda dapat mengelola bagian ini',
	'info_1_article' => '1 artikel',
	'info_activer_cookie' => 'Anda apat mengaktifkan <b>cookie administrasi</b>, yang memperbolehkan anda
 untuk berpindah-pindah dengan mudah antara situs umum dan area pribadi.',
	'info_administrateur' => 'Administrator',
	'info_administrateur_1' => 'Administrator',
	'info_administrateur_2' => 'situs (<i>gunakan dengan penuh kehati-hatian</i>)',
	'info_administrateur_site_01' => 'Jika anda adalah seorang administrator situs, silakan',
	'info_administrateur_site_02' => 'klik tautan ini',
	'info_administrateurs' => 'Administrator',
	'info_administrer_rubrique' => 'Anda dapat mengelola bagian ini',
	'info_adresse' => 'ke alamat:',
	'info_adresse_url' => 'URL situs umum anda',
	'info_aide_en_ligne' => 'Bantuan Online SPIP',
	'info_ajout_image' => 'Ketika anda menambahkan gambar sebagai lampiran pada sebuah artikel,
		SPIP dapat secara otomatis membuat gambar kecil dari
		gambar yang dimasukkan. Ini bermanfaat ,sebagai contoh, untuk membuat
		sebuah galeri gambar atau portfolio.',
	'info_ajouter_rubrique' => 'Tambah sebuah bagian untuk dikelola:',
	'info_annonce_nouveautes' => 'Pengumuman-pengumuman berita terbaru',
	'info_article' => 'artikel',
	'info_article_2' => 'artikel',
	'info_article_a_paraitre' => 'Artikel-artikel bertanggal yang akan dipublikasikan',
	'info_articles_02' => 'Artikel',
	'info_articles_2' => 'Artikel',
	'info_articles_auteur' => 'Artikel-artikel penulis ini',
	'info_articles_trouves' => 'Artikel ditemukan',
	'info_attente_validation' => 'Validasi tertunda artikel-artikel anda',
	'info_aujourdhui' => 'hari ini:',
	'info_auteurs' => 'Penulis',
	'info_auteurs_par_tri' => 'Penulis@partri@',
	'info_auteurs_trouves' => 'Penulis ditemukan',
	'info_authentification_externe' => 'Ototentikasi eksternal',
	'info_avertissement' => 'Peringatan',
	'info_base_installee' => 'Struktur database anda telah diinstal.',
	'info_chapeau' => 'Dek',
	'info_chapeau_2' => 'Introduksi:',
	'info_chemin_acces_1' => 'Pilihan: <b>Path akses dalam direktori</b>',
	'info_chemin_acces_2' => 'Mulai sekarang, anda harus mengkonfigurasi path akses ke informasi direktori. Informasi ini penting untuk membaca profil pengguna yang disimpan dalam direktori.',
	'info_chemin_acces_annuaire' => 'Pilihan: <b>Path akses dalam direktori</B>',
	'info_choix_base' => 'Langkah ketiga:',
	'info_classement_1' => ' dari @liste@',
	'info_classement_2' => ' dari @liste@',
	'info_code_acces' => 'Jangan lupa kode akses anda!',
	'info_config_suivi' => 'Jika alamat ini berkaitan dengan suatu daftar surat, anda dapat mengindikasikan di bawah alamat di mana pengunjung situs dapat mendaftarkan diri. Alamat ini dapat berupa URL (sebagai contoh halaman registrasi daftar surat melalui web), atau alamat e-mail dengan subyek yang spesifik (contoh: <tt>@adresse_suivi@?subject=subscribe</tt>):',
	'info_config_suivi_explication' => 'Anda dapat berlangganan daftar surat situs ini. Anda akan menerima melalui e-mail secara otomatis, pengumuman-pengumuman yang berkenaan dengan artikel-artikel dan berita-berita yang dikirim untuk publikasi.',
	'info_confirmer_passe' => 'Konfirmasi kata sandi baru:',
	'info_connexion_base' => 'Langkah kedua: <b>Percobaan untuk koneksi ke database</B>',
	'info_connexion_ldap_ok' => 'Koneksi LDAP anda berhasil.</b><p> Anda dapat meneruskan ke langkah selanjutnya.</p>', # MODIF
	'info_connexion_mysql' => 'Langkah pertama: <b>Koneksi SQL anda</b>',
	'info_connexion_ok' => 'Koneksi berhasil.',
	'info_contact' => 'Kontak',
	'info_contenu_articles' => 'Isi artikel',
	'info_creation_paragraphe' => '(Untuk membuat paragraf, anda cukup meninggalkan baris-baris kosong.)', # MODIF
	'info_creation_rubrique' => 'Sebelum bisa menulis artikel,<br /> anda harus membuat paling tidak satu bagian.<br />',
	'info_creation_tables' => 'Langkah keempat: <b>Pembuatan tabel-tabel database</b>',
	'info_creer_base' => '<b>Buat</b> sebuah database baru:',
	'info_dans_rubrique' => 'Dalam bagian:',
	'info_date_publication_anterieure' => 'Tanggal publikasi sebelumnya:',
	'info_date_referencement' => 'TANGGAL REFERENSI SITUS INI:',
	'info_derniere_etape' => 'Langkah terakhir: <b>Selesai!',
	'info_descriptif' => 'Deskripsi:',
	'info_discussion_cours' => 'Diskusi-diskusi yang sedang berlangsung',
	'info_ecrire_article' => 'Sebelum dapat menulis artikel, anda harus membuat paling tidak satu bagian.',
	'info_email_envoi' => 'Alamat e-mail pengirim (opsional)',
	'info_email_envoi_txt' => 'Masukkan alamat e-mail pengirim yang digunakan untuk mengirim e-mail (secara standar, alamat penerima digunakan sebagai alamat pengirim) :',
	'info_email_webmestre' => 'Alamat e-mail webmaster (opsional)', # MODIF
	'info_envoi_email_automatique' => 'Pengiriman otomatis',
	'info_envoyer_maintenant' => 'Kirim sekarang',
	'info_etape_suivante' => 'Lanjut ke langkah berikutnya',
	'info_etape_suivante_1' => 'Anda dapat pindah ke langkah selanjutnya.',
	'info_etape_suivante_2' => 'Anda dapat pindah ke langkah selanjutnya.',
	'info_exportation_base' => 'ekspor database ke @archive@',
	'info_facilite_suivi_activite' => 'Untuk menfasilitasi tindak lanjut dari aktivitas editorial situs;
  SPIP dapat mengirimkan notifikasi melalui e-mail, ke daftar surat seorang editor,
  sebagai contoh permohonan publikasi dan validasi artikel.',
	'info_fichiers_authent' => 'Berkas ototentikasi ".htpasswd"',
	'info_forums_abo_invites' => 'Situs anda berisikan forum-forum berlangganan; pengunjung dapat mendaftarkan diri pada forum-forum tersebut di situs umum.',
	'info_gauche_admin_tech' => '<b>Hanya administrator yang memiliki akses ke halaman ini.</b><p> Halaman ini memberikan akses ke berbagai tugas pemeliharaan teknis. Beberapa di antaranya memerlukan proses ototentikasi tersendiri yang membutuhkan akses FTP ke situs web.</p>', # MODIF
	'info_gauche_admin_vider' => '<b>Hanya administrator yang memiliki akses ke halaman ini.</b><p> Halaman ini memberikan akses ke berbagai tugas pemeliharaan teknis. Beberapa di antaranya memerlukan proses ototentikasi tersendiri yang membutuhkan akses FTP ke situs web.</p>', # MODIF
	'info_gauche_auteurs' => 'Anda akan menemukan seluruh penulis situs di sini.
 Status dari setiap penulis ditunjukkan oleh warna icon (administrator = hijau; editor = kuning).',
	'info_gauche_auteurs_exterieurs' => 'Penulis eksternal, tanpa akses ke situs, ditunjukkan oleh icon biru; penulis yang dihapus oleh icon warna keranjang sampah.', # MODIF
	'info_gauche_messagerie' => 'Sistem pesan mengizinkan anda bertukar pesan dengan sesama editor, untuk menyimpan memo (untuk keperluan pribadi anda) atau untuk menampilkan pengumuman di halaman depan area pribadi (jika anda seorang administrator).',
	'info_gauche_statistiques_referers' => 'Halaman ini menampilkan daftar <i>pereferensi</I>, yakni situs-situs yang memuat tautan ke situs anda, hanya untuk kemarin dan hari ini: sesungguhnya daftar ini diperbaharui setiap 24 jam.',
	'info_gauche_visiteurs_enregistres' => 'Anda akan menemukan di sini para pengunjung
	terdaftar di area umum situs (forum-forum berlangganan).',
	'info_generation_miniatures_images' => 'Membuat gambar-gambar kecil',
	'info_hebergeur_desactiver_envoi_email' => 'Sejumlah hosting menonaktifkan pengiriman e-mail
  otomatis di server mereka. Dalam hal ini fitur-fitur SPIP berikut tidak
  dapat diimplementasikan.',
	'info_hier' => 'kemarin:',
	'info_identification_publique' => 'Identitas umum anda...',
	'info_image_process' => 'Pilih metode terbaik untuk membuat gambar kecil dengan mengklik gambar yang terkait.',
	'info_image_process2' => '<b>Catatan:</b> <i>Jika anda tidak dapat melihat gambar, berarti server anda tidak dikonfigurasi untuk menggunakan peralatan yang ada. Jika anda ingin menggunakan fitur-fitur ini, hubungi bagian teknis penyedia hosting anda dan minta ekstensi «GD» atau «Imagick» diinstal.</i>', # MODIF
	'info_images_auto' => 'Gambar secara otomatis dikalkulasi',
	'info_informations_personnelles' => 'Langkah kelima: <b>Informasi pribadi</B>',
	'info_inscription_automatique' => 'Registrasi otomatis editor-editor baru',
	'info_jeu_caractere' => 'Set karakter situs',
	'info_jours' => 'hari',
	'info_laisser_champs_vides' => 'biarkan kolom-kolom ini kosong)',
	'info_langues' => 'Bahasa-bahasa situs',
	'info_ldap_ok' => 'Ototentikasi LDAP diinstal.',
	'info_lien_hypertexte' => 'Tautan web:',
	'info_liste_redacteurs_connectes' => 'Daftar editor-editor terkoneksi',
	'info_login_existant' => 'Log masuk ini sudah ada.',
	'info_login_trop_court' => 'Log masuk terlalu pendek.',
	'info_maximum' => 'maksimum:',
	'info_meme_rubrique' => 'Dalam bagian yang sama',
	'info_message_en_redaction' => 'Pesan-pesan anda dalam proses',
	'info_message_technique' => 'Pesan teknis:',
	'info_messagerie_interne' => 'Sistem pesan internal',
	'info_mise_a_niveau_base' => 'Pembaharuan database SQL',
	'info_mise_a_niveau_base_2' => '{{Peringatan!}} Anda telah menginstal berkas SPIP
  {yang lebih tua} daripada berkas yang terdapat sebelumnya
  di situs ini: database anda terancam hilang dan situs anda
  tidak akan bekerja sebagaimana mestinya lagi.<br />{{Instal kembali
  berkas-berkas SPIP}}',
	'info_modifier_rubrique' => 'Modifikasi bagian:',
	'info_modifier_titre' => 'Modifikasi: @titre@',
	'info_mon_site_spip' => 'Situs SPIP saya',
	'info_moyenne' => 'rata-rata:',
	'info_multi_cet_article' => 'Bahasa artikel ini:',
	'info_multi_langues_choisies' => 'Silakan pilih di bawah bahasa yang tersedia untuk editor situs anda.
  Bahasa-bahasa yang telah digunakan oleh situs anda (di daftar paling atas) tidak dapat dinonaktifkan.',
	'info_multi_secteurs' => '... hanya untuk bagian-bagian yang berlokasi di root?',
	'info_nom' => 'Nama',
	'info_nom_destinataire' => 'Nama penerima',
	'info_nom_site' => 'Nama situs anda',
	'info_nombre_articles' => '@nb_articles@ artikel,',
	'info_nombre_rubriques' => '@nb_rubriques@ bagian,',
	'info_nombre_sites' => '@nb_sites@ situs,',
	'info_non_deplacer' => 'Jangan pindahkan...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP dapat mengirimkan pengumuman-pengumuman terbaru situs secara teratur.
		(artikel-artikel dan berita-berita yang baru saja dipublikasi).',
	'info_non_envoi_liste_nouveautes' => 'Jangan kirim daftar berita-berita terbaru',
	'info_non_modifiable' => 'tidak dapat dimodifikasi',
	'info_non_suppression_mot_cle' => 'Saya tidak ingin menghapus kata kunci ini.',
	'info_notes' => 'Catatan kaki',
	'info_nouvel_article' => 'Artikel baru',
	'info_nouvelle_traduction' => 'Terjemahan baru:',
	'info_numero_article' => 'NOMOR ARTIKEL:',
	'info_obligatoire_02' => '[Dibutuhkan]', # MODIF
	'info_option_accepter_visiteurs' => 'Izinkan registrasi pengunjung dari situs umum',
	'info_option_ne_pas_accepter_visiteurs' => 'Tolak registrasi pengunjung',
	'info_options_avancees' => 'OPSI-OPSI LANJUTAN',
	'info_ou' => 'atau...',
	'info_page_interdite' => 'Halaman terlarang',
	'info_par_nom' => 'berdasarkan nama',
	'info_par_nombre_article' => '(berdasarkan jumlah artikel)',
	'info_par_statut' => 'berdasarkan status',
	'info_par_tri' => '(Oleh @tri@)',
	'info_passe_trop_court' => 'Kata sandi terlalu pendek.',
	'info_passes_identiques' => 'Dua kata sandi tidak identik.',
	'info_plus_cinq_car' => 'lebih dari 5 karakter',
	'info_plus_cinq_car_2' => '(Lebih dari 5 karakter)',
	'info_plus_trois_car' => '(Lebih dari 3 karakter)',
	'info_popularite' => 'popularitas: @popularite@; kunjungan: @visites@',
	'info_post_scriptum' => 'Postscript',
	'info_post_scriptum_2' => 'Postscript:',
	'info_pour' => 'untuk',
	'info_preview_texte' => 'Ada kemungkinan melihat situs terlebih dahulu seolah-olah semua artikel dan berita (yang paling tidak memiliki status "terkirim") telah dipublikasi. Apakah mode preview ini sebaiknya dibatasi hanya kepada administrator, terbuka untuk semua penulis atau dinonaktifkan selama-lamanya?', # MODIF
	'info_procedez_par_etape' => 'silakan dilanjutkan langkah demi langkah',
	'info_procedure_maj_version' => 'prosedur pembaharuan hendaknya dijalankan untuk
	mengadaptasi database degan versi terbaru SPIP.',
	'info_proxy_ok' => 'Percobaan proxy berhasil.',
	'info_ps' => 'P.S.',
	'info_publier' => 'publikasi',
	'info_publies' => 'Artikel anda dipublikasi secara online',
	'info_question_accepter_visiteurs' => 'Jika templat situs anda mengizinkan pengunjung untuk mendaftar tanpa perlu memasuki area pribadi, silakan aktifkan opsi berikut:',
	'info_question_inscription_nouveaux_redacteurs' => 'Apakah anda mengizinkan registrasi editor baru dari
  situs yang dipublikasi? Jika anda setuju, pengunjung dapat mendaftar
  melalui formulir terotomasi, dan akan mengakses area pribadi untuk
  melihat artikel-artikel mereka. <blockquote><i>Selama proses registrasi,
  pengguna menerima sebuah e-mail terotomasi
  yang memberikan kode akses ke situs pribadi. Sejumlah
  hosting menonaktifkan pengiriman e-mail di server mereka:
  dalam hal ini ini registrasi terotomasi tidak dapat
  diimplementasikan.', # MODIF
	'info_qui_edite' => '@nom_auteur_modif@ a travaillé sur ce contenu il y a @date_diff@ minutes', # MODIF
	'info_racine_site' => 'Root situs',
	'info_recharger_page' => 'Silakan buka kembali halaman ini beberapa saat lagi.',
	'info_recherche_auteur_zero' => 'Tidak ada hasil untuk "@cherche_auteur@".',
	'info_recommencer' => 'Silakan coba lagi.',
	'info_redacteur_1' => 'Redaktur',
	'info_redacteur_2' => 'memiliki akses ke area pribadi (<i>disarankan</i>)',
	'info_redacteurs' => 'Editor',
	'info_redaction_en_cours' => 'PENGEDITAN DALAM PROSES',
	'info_redirection' => 'Pengalihan tujuan',
	'info_refuses' => 'Artikel anda ditolak',
	'info_reglage_ldap' => 'Pilihan: <b>Menyesuaikan impor LDAP</b>',
	'info_renvoi_article' => '<b>Pengalihan tujuan.</B> Artikel ini mengarah pada halaman:',
	'info_reserve_admin' => 'Hanya administrator yang dapat memodifikasi alamat ini.',
	'info_restreindre_rubrique' => 'Batasi manajemen ke bagian:',
	'info_resultat_recherche' => 'Hasil-hasil pencarian:',
	'info_rubriques' => 'Bagian',
	'info_rubriques_02' => 'bagian',
	'info_rubriques_trouvees' => 'Bagian ditemukan',
	'info_sans_titre' => 'Tidak berjudul',
	'info_selection_chemin_acces' => '<b>Pilih</b> di bawah path akses dalam direktori:',
	'info_signatures' => 'tanda tangan',
	'info_site' => 'Situs',
	'info_site_2' => 'situs:',
	'info_site_min' => 'situs',
	'info_site_reference_2' => 'Situs referensi',
	'info_site_web' => 'SITUS WEB:', # MODIF
	'info_sites' => 'situs',
	'info_sites_lies_mot' => 'Situs-situs referensi yang terasosiasi dengan kata kunci ini',
	'info_sites_proxy' => 'Menggunakan proxy',
	'info_sites_trouves' => 'Situs ditemukan',
	'info_sous_titre' => 'Sub judul:',
	'info_statut_administrateur' => 'Administrator',
	'info_statut_auteur' => 'Status penulis ini:', # MODIF
	'info_statut_auteur_a_confirmer' => 'Pendaftaran yang perlu dikonfirmasi',
	'info_statut_auteur_autre' => 'Status lainnya:',
	'info_statut_redacteur' => 'Editor',
	'info_statut_utilisateurs_1' => 'Status standar para pengguna yang diimpor',
	'info_statut_utilisateurs_2' => 'Pilih status yang diberikan kepada orang-orang yang terdapat di direktori LDAP ketika terkoneksi pertama kali. Nanti anda dapat memodifikasi status tersebut untuk setiap penulis berdasarkan kasus per kasus.',
	'info_suivi_activite' => 'Tindak lanjut aktivitas editorial',
	'info_surtitre' => 'Judul atas:',
	'info_syndication_integrale_1' => 'Situs anda menyediakan berkas-berkas sindikasi (lihat <a href="@url@">@titre@</a>).',
	'info_syndication_integrale_2' => 'Apakah anda ingin mengirim seluruh artikel atau ringkasannya saja yang terdiri dari beberapa ratus karakter?',
	'info_table_prefix' => 'Data situs ini disimpan di tabel bernama <tt><b>spip</b>_articles</tt>, <tt><b>spip</b>_rubriques</tt>, dst. Jika anda menginstal sejumlah situs dalam database yang sama, anda dapat mengubah prefiks dari nama tabel (Catatan: Gunakan hanya huruf-huruf kecil dan tidak beraksen.).',
	'info_taille_maximale_vignette' => 'Ukuran maksimum gambar-gambar kecil yang dihasilkan oleh sistem:',
	'info_terminer_installation' => 'Anda dapat menyelesaikan sekarang proses instalasi standar.',
	'info_texte' => 'Teks',
	'info_texte_explicatif' => 'Teks penjelasan',
	'info_texte_long' => '(Teks terlalu panjang: akan muncul dalam beberapa bagian yang akan disusun kembali setelah validasi.)',
	'info_texte_message' => 'Teks pesan anda:', # MODIF
	'info_texte_message_02' => 'Teks pesan',
	'info_titre' => 'Judul:',
	'info_total' => 'total:',
	'info_tous_articles_en_redaction' => 'Semua artikel dalam proses',
	'info_tous_articles_presents' => 'Semua artikel yang dipublikasi dalam bagian ini',
	'info_tous_les' => 'setiap:',
	'info_tout_site' => 'Seluruh situs',
	'info_tout_site2' => 'Artikel-artikel belum diterjemahkan ke dalam bahasa ini.',
	'info_tout_site3' => 'Artikel telah diterjemahkan ke dalam bahasa ini, tapi sejumlah modifikasi telah dibuat untuk artikel referensi. Oleh karenanya terjemahan memerlukan pembaharuan.',
	'info_tout_site4' => 'Artikel telah diterjemahkan ke dalam bahasa ini, dan ini merupakan terjemahan yang terbaru.',
	'info_tout_site5' => 'Artikel asli.',
	'info_tout_site6' => '<b>Peringatan:</b> hanya artikel-artikel asli yang ditampilkan.
Terjemahan diasosiasikan dengan yang asli,
dalam warna yang menunjukkan statusnya:',
	'info_travail_colaboratif' => 'Kolaborasi kerja pada artikel',
	'info_un_article' => 'sebuah artikel,',
	'info_un_site' => 'sebuah situs,',
	'info_une_rubrique' => 'sebuah bagian,',
	'info_une_rubrique_02' => '1 bagian',
	'info_url' => 'URL:',
	'info_urlref' => 'Tautan web:',
	'info_utilisation_spip' => 'SPIP siap untuk digunakan...',
	'info_visites_par_mois' => 'Tampilan bulanan:',
	'info_visiteur_1' => 'Pengunjung',
	'info_visiteur_2' => 'situs umum',
	'info_visiteurs' => 'Pengunjung',
	'info_visiteurs_02' => 'Pengunjung situs umum',
	'install_echec_annonce' => 'Instalasi ini tidak akan bekerja, atau akan menghasilkan situs yang tidak berfungsi sebagaimana mestinya...',
	'install_extension_mbstring' => 'SPIP tidak dapat bekerja dengan:',
	'install_extension_php_obligatoire' => 'SPIP membutuhkan sebuah ekstensi php:',
	'install_php_version' => 'Versi PHP @version@ terlalu tua (minimum = @minimum@)',
	'install_select_langue' => 'Pilih sebuah bahasa dengan mengklik tombol "selanjutnya" untuk memulasi prosedur instalasi.',
	'intem_redacteur' => 'editor',
	'item_accepter_inscriptions' => 'Izinkan pendaftaran',
	'item_activer_messages_avertissement' => 'Aktifkan pesan-pesan peringatan',
	'item_administrateur_2' => 'administrator',
	'item_afficher_calendrier' => 'Tampilkan dalam kalender',
	'item_autoriser_syndication_integrale' => 'Ikut sertakan semua artikel dalam berkas sindikasi',
	'item_choix_administrateurs' => 'administrator',
	'item_choix_generation_miniature' => 'Buat gambar-gambar kecil secara otomatis.',
	'item_choix_non_generation_miniature' => 'Jangan buat gambar-gambar kecil.',
	'item_choix_redacteurs' => 'editor',
	'item_choix_visiteurs' => 'pengunjung situs umum',
	'item_creer_fichiers_authent' => 'Buat berkas .htpasswd',
	'item_login' => 'Log masuk',
	'item_mots_cles_association_articles' => 'artikel',
	'item_mots_cles_association_rubriques' => 'bagian',
	'item_mots_cles_association_sites' => 'situs-situs referensi atau tersindikasi.',
	'item_non' => 'No',
	'item_non_accepter_inscriptions' => 'Jangan izinkan pendaftaran',
	'item_non_activer_messages_avertissement' => 'Tidak ada pesan-pesan kesalahan',
	'item_non_afficher_calendrier' => 'Jangan tampilkan dalam kalender',
	'item_non_autoriser_syndication_integrale' => 'Kirim ringkasan saja',
	'item_non_creer_fichiers_authent' => 'Jangan buat berkas-berkas ini',
	'item_non_publier_articles' => 'Jangan publikasi artikel sebelum tanggal publikasinya.',
	'item_nouvel_auteur' => 'Penulis baru',
	'item_nouvelle_rubrique' => 'Bagian baru',
	'item_oui' => 'Ya',
	'item_publier_articles' => 'Publikasi artikel tanpa menghiraukan tanggal publikasinya.',
	'item_reponse_article' => 'Balasan pada artikel',
	'item_visiteur' => 'pengunjung',

	// J
	'jour_non_connu_nc' => 'tidak dikenal',

	// L
	'lien_ajouter_auteur' => 'Tambahkan penulis ini',
	'lien_email' => 'e-mail',
	'lien_nom_site' => 'NAMA SITUS:',
	'lien_retirer_auteur' => 'Hapus penulis',
	'lien_site' => 'situs',
	'lien_tout_deplier' => 'Buka semuanya',
	'lien_tout_replier' => 'Tutup semuanya',
	'lien_tout_supprimer' => 'Hapus semua',
	'lien_trier_nom' => 'Disusun berdasarkan nama',
	'lien_trier_nombre_articles' => 'Disusun berdasarkan jumlah artikel',
	'lien_trier_statut' => 'Disusun berdasarkan status',
	'lien_voir_en_ligne' => 'LIHAT ONLINE:',
	'logo_article' => 'LOGO ARTIKEL', # MODIF
	'logo_auteur' => 'LOGO PENULIS', # MODIF
	'logo_rubrique' => 'LOGO BAGIAN', # MODIF
	'logo_site' => 'LOGO SITUS INI', # MODIF
	'logo_standard_rubrique' => 'LOGO STANDAR UNTUK BAGIAN', # MODIF
	'logo_survol' => 'LOGO SAMARAN', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'Pilih database anda',
	'module_fichier_langue' => 'Berkas bahasa',
	'module_raccourci' => 'Jalan pintas',
	'module_texte_affiche' => 'Teks tampilan',
	'module_texte_explicatif' => 'Anda dapat memasukkan jalan-jalan pintas berikut ke dalam templat situs anda. Mereka akan diterjemahkan secara otomatis dalam berbagai bahasa bila berkas bahasanya telah tersedia.',
	'module_texte_traduction' => 'Berkas bahasa « @module@ » tersedia di:',
	'mois_non_connu' => 'tidak dikenal',

	// O
	'onglet_repartition_actuelle' => 'sekarang',

	// P
	'plugin_etat_developpement' => 'dalam pengembangan',
	'plugin_etat_experimental' => 'eksperimental',
	'plugin_etat_stable' => 'stabil',
	'plugin_etat_test' => 'sedang dites',
	'plugins_liste' => 'Daftar plugin',
	'protocole_ldap' => 'Versi protokol:',

	// R
	'repertoire_plugins' => 'Directori:',
	'required' => '[Dibutuhkan]', # MODIF

	// S
	'statut_admin_restreint' => '(admin terbatas)', # MODIF

	// T
	'taille_cache_image' => 'Gambar-gambar dikalkulasi secara otomatis oleh SPIP (gambar kecil, judul yang ditransformasi ke dalam grafik, formula matematika dalam format Tex, dll.) dengan jumlah keseluruhan @taille@ di direktori @dir@ .',
	'taille_cache_infinie' => 'Situs ini tidak memiliki batasan tetap untuk ukuran direktori cache.',
	'taille_cache_maxi' => 'SPIP sedang mencoba untuk membatasi ukuran direktori cache sebesar lebih kurang <b>@octets@</b> data.',
	'taille_cache_octets' => 'Ukuran cache sekarang adalah @octets@.', # MODIF
	'taille_cache_vide' => 'Cache kosong.',
	'taille_repertoire_cache' => 'Ukuran cache saat ini',
	'text_article_propose_publication' => 'Artikel yang dikirimkan untuk publikasi. Jangan segan-segan memberikan opini anda melalui forum yang yang terlampir di artikel ini (di bagian bawah halaman).', # MODIF
	'texte_acces_ldap_anonyme_1' => 'Sejumlah server LDAP tidak mengizinkan akses anonim. Dalam hal ini anda harus memberikan satu pengidentifikasi akses awal agar bisa mencari informasi dalam direktori setelahnya. Walaupun demikian, dalam banyak kasus kolom-kolom berikut dapat dibiarkan kosong tidak terisi.',
	'texte_admin_effacer_01' => 'Perintah ini menghapus <i>semua</i> isi database,
termasuk <i>semua</i> parameter akses untuk editor dan administrator. Setelah mengeksekusinya, anda sebaiknya
menginstal kembali SPIP untuk membuat database baru dan akses administrator pertama.',
	'texte_adresse_annuaire_1' => '( Jika direktori anda diinstal di mesin yang sama dengan situs web anda, kemungkinan besar ini adalah «localhost».)',
	'texte_ajout_auteur' => 'Penulis berikut telah ditambahkan ke artikel:',
	'texte_annuaire_ldap_1' => 'Jika anda memiliki akses ke sebuah direktori (LDAP), anda dapat menggunakannya untuk mengimpor pengguna secara otomatis di bawah SPIP.',
	'texte_article_statut' => 'Status artikel:',
	'texte_article_virtuel' => 'Artikel maya',
	'texte_article_virtuel_reference' => '<b>Artikel maya:</b> artikel referensi di situs SPIP anda, yang dialihkan ke lain URL. Untuk menghapus pengalihan, hapuslah URL di atas.',
	'texte_aucun_resultat_auteur' => 'Tidak ada hasil untuk "@cherche_auteur@".',
	'texte_auteur_messagerie' => 'Situs ini dapat memonitor secara terus-menerus daftar editor-editor yang terkoneksi, yang mengizinkan anda untuk bertukar pesan secara langsung. Anda dapat memilih untuk tidak muncul dalam daftar ini (yang membuat anda kemudian, "tak terlihat" di hadapan pengguna lainnya).',
	'texte_auteurs' => 'PENULIS',
	'texte_choix_base_1' => 'Pilih database anda:',
	'texte_choix_base_2' => 'Server SQL berisikan sejumlah database.',
	'texte_choix_base_3' => '<b>Pilih</B> di bawah salah satu yang diberikan hosting anda kepada anda:',
	'texte_choix_table_prefix' => 'Prefiks untuk tabel:',
	'texte_compte_element' => '@count@ elemen',
	'texte_compte_elements' => '@count@ elemen',
	'texte_connexion_mysql' => 'Merujuk kepada informasi yang diberikan hosting anda kepada anda: mereka seharusnya memberikan anda, jika hosting anda mendukung SQL, kode koneksi ke server SQL.', # MODIF
	'texte_contenu_article' => '(Isi artikel dalam beberapa kata.)',
	'texte_contenu_articles' => 'Berdasarkan tampilan yang dipilih untuk situs anda, anda dapat memilih
  sejumlah elemen artikel tidak digunakan.
  Gunakan daftar berikut untuk memilih elemen mana yang akan dipakai.',
	'texte_crash_base' => 'Jika database anda
			rusak, anda dapat mencoba memperbaikinya
			secara otomatis.',
	'texte_creer_rubrique' => 'Sebelum dapat menulis artikel,<br /> anda harus membuat sebuah bagian.',
	'texte_date_creation_article' => 'TANGGAL PENULISAN ARTIKEL:',
	'texte_date_publication_anterieure' => 'Tanggal publikasi awal:',
	'texte_date_publication_anterieure_nonaffichee' => 'Sembunyikan data publikasi awal.',
	'texte_date_publication_article' => 'TANGGAL PUBLIKASI ONLINE:',
	'texte_descriptif_rapide' => 'Deskripsi singkat',
	'texte_effacer_base' => 'Hapus database SPIP',
	'texte_en_cours_validation' => 'Artikel-artikel dan berita-berita berikut dikirim untuk publikasi. Jangan segan-segan memberikan opini anda melalui forum yang terlampir di dalamnya.', # MODIF
	'texte_enrichir_mise_a_jour' => 'Anda dapat memperkaya tampilan teks anda dengan menggunakan «jalan pintas typografis».',
	'texte_fichier_authent' => '<b>Haruskah SPIP membuat berkas <tt>.htpasswd</tt>
  dan <tt>.htpasswd-admin</tt> dalam direktori @dossier@?</b><p>
  Berkas-berkas ini dapat digunakan untuk membatasi akses penulis
  dan administrator di bagian lain situs anda
  (sebagai contoh, program statistik eksternal).</p><p>
  Jika anda tidak memerlukan berkas-berkas tersebut, anda dapat
  membiarkannya dengan nilai standar yang diberikan (tidak ada 
  pemmbuat berkas-berkas baru).</p>', # MODIF
	'texte_informations_personnelles_1' => 'Sistem akan memberikan anda sekarang akses tersendiri ke situs.',
	'texte_informations_personnelles_2' => '(Catatan: jika ini adalah instalasi kembali, dan akses anda masih berlaku, anda dapat', # MODIF
	'texte_introductif_article' => '(Teks Pengantar artikel.)',
	'texte_jeu_caractere' => 'Anda disarankan menggunakan aksara universal (<tt>utf-8</tt>) di situs anda. Ini memungkinkan untuk menampilkan teks dalam segala bahsa. Browser modern tidak akan mengalami kesulitan dalam menangani set karakter ini.',
	'texte_jeu_caractere_3' => 'Situs anda saat ini menggunakan set karakter ini:',
	'texte_jeu_caractere_4' => 'Jika itu tidak berkaitan dengan situasi yang anda miliki dengan data anda (sebagai contoh, setelah pemulihan database anda dari backup), atau jika <em>anda mengkonfigurasi situs ini</em> dan berkeinginan menggunakan set karakter yang berbeda, silakan tunjukkan set karakter di sini:',
	'texte_login_ldap_1' => '(Biarkan kosong untuk akses anonim atau masukkan path lengkap, sebagai contoh «<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>».)',
	'texte_login_precaution' => 'Peringatan! Ini adalah log masuk yang anda gunakan untuk terkoneksi sekarang.
	Gunakan formulir ini dengan hati-hati...',
	'texte_mise_a_niveau_base_1' => 'Anda harus memperbaharui berkas-berkas SPIP.
	Sekarang anda harus memperbaharui database situs.',
	'texte_modifier_article' => 'Modifikasi artikel:',
	'texte_multilinguisme' => 'Jika anda ingin mengelola artikel-artikel dalam beberapa bahasa, dengan navigasi yang kompleks, anda dapat menambah sebuah menu pemilih bahasa di artikel dan/atau bagian, sesuai dengan organisasi dari situs anda.', # MODIF
	'texte_multilinguisme_trad' => 'Selain itu, anda juga dapat mengaktifkan sistem manajemen tautan di antara terjemahan yang berbeda dari sebuah artikel.', # MODIF
	'texte_non_compresse' => '<i>tidak dikompresi</i> (server anda tidak mendukung fitur ini)',
	'texte_nouvelle_version_spip_1' => 'Anda baru saja menginstal versi terbaru SPIP.',
	'texte_nouvelle_version_spip_2' => 'Versi terbaru ini membutuhkan pembaharuan secara menyeluruh daripada biasanya. Jika anda adalah webmaster situs ini, silakan hapus berkas @connect@ dan jalankan kembali instalasi untuk memperbaharui paramater-parameter koneksi database anda. <p>(Catatan: Jika anda lupa paramater-parameter koneksi database anda, silakan lihat berkas @connect@ sebelum menghapusnya!)</p>', # MODIF
	'texte_operation_echec' => 'Kembali ke halaman sebelumnya, pilih database lain atau buat yang baru. Verifikasi informasi yang diberikan oleh hosting anda.',
	'texte_plus_trois_car' => 'lebih dari 3 karakter',
	'texte_plusieurs_articles' => 'Sejumla penulis ditemukan untuk "@cherche_auteur@":',
	'texte_port_annuaire' => '(Nilai standar dipakai pada umumnya.)',
	'texte_presente_plugin' => 'Halaman ini menampilkan daftar plugin yang tersedia di situs. Aktifkan plugin yang anda butuhkan dengan memberi tanda di kotak yang bersangkutan.',
	'texte_proposer_publication' => 'Ketika artikel anda selesai ditulis,<br /> anda dapat mengirimkannya untuk publikasi.',
	'texte_proxy' => 'Dalam beberapa kasus (intranet, jaringan pribadi...),
		<i>proxy HTTP</i> perlu digunakan untuk menjangkau situs-situs tersindikasi.
		Kalau memang ada proxy, masukkan alamat di bawah,
		<tt><html>http://proxy:8080</html></tt>. Pada umumnya,
		anda akan membiarkan kotak ini kosong.',
	'texte_publication_articles_post_dates' => 'Perilaku apa SPIP seharusnya terapkan berkaitan dengan artikel-artikel
		yang publikasinya diset untuk
		sebuah tanggal di masa depan?',
	'texte_rappel_selection_champs' => '[Ingat untuk memilih kolom ini dengan benar.]',
	'texte_recalcul_page' => 'Jika anda hanya ingin
memperbaharui satu halaman, anda sebaiknya melakukannya dari area umum dan gunakan tombol « perbaharui ».',
	'texte_recuperer_base' => 'Perbaiki database',
	'texte_reference_mais_redirige' => 'artikel referensi di situs SPIP anda, tapi mengarah ke URL lain.',
	'texte_requetes_echouent' => '<b>Wetika sejumlah query SQL gagal
  secara sistematis dan tanpa alasan yang jelas, bisa jadi
  permasalahannya adalah database itu sendiri.</b><p>
  SQL memiliki fitur yang dapat memperbaiki tabel-tabelnya
  ketika mereka secara tidak sengaja menjadi rusak.
  Di sini, anda dapat mencoba melakukan perbaikan tersebut;
  jika gagal, anda sebaiknya menyimpan salinan dari tampilan
  yang mungkin dapat dijadikan petunjuk apa yang salah...</p><p>
  Jika permasalahan ini msih berlanjut, hubungi hosting anda.</p>', # MODIF
	'texte_selection_langue_principale' => 'Anda dapat memilih di bawah "bahasa utama" situs. Untungnya, pilihan ini tidak membatasi anda menulis artikel dalam bahasa yang dipilih, tapi mengizinkan anda untuk menentukan

<ul><li> format tanggal standar di situs umum</li>

<li> mesin typografis yang akan digunakan oleh SPIP untuk menghasilkan teks;</li>

<li> bahasa yang digunakan di formulir-formulir situs umum</li>

<li> bahasa standar yang ditampilkan di area pribadi.</li></ul>',
	'texte_sous_titre' => 'Sub judul',
	'texte_statistiques_visites' => '(balok gelap:  Minggu / kurva gelap: tingkat rata-rata)',
	'texte_statut_attente_validation' => 'validasi yang tertunda',
	'texte_statut_publies' => 'dipublikasi online',
	'texte_statut_refuses' => 'ditolak',
	'texte_suppression_fichiers' => 'Gunakan perintah ini untuk menghapus semua berkas
dalam cache SPIP. Ini mengizinkan anda, antara lain, untuk memaksa semua halaman diperbaharui jika
anda memasukkan modifikasi yang penting di grafik atau struktur situs.',
	'texte_sur_titre' => 'Judul atas',
	'texte_table_ok' => ': tabel ini OK.',
	'texte_tentative_recuperation' => 'Usaha perbaikan',
	'texte_tenter_reparation' => 'Usaha untuk memperbaiki database.',
	'texte_test_proxy' => 'Untuk mencoba proxy ini, masukkan alamat sebuah situs web di sini
				yang ingin anda tes.',
	'texte_titre_02' => 'Subyek:',
	'texte_titre_obligatoire' => '<b>Judul</b> [Dibutuhkan]',
	'texte_travail_article' => '@nom_auteur_modif@ telah bekerja di artikel ini @date_diff@ menit yang lalu',
	'texte_travail_collaboratif' => 'Jika beberapa editor sering bekerja sama dalam artikel yang sama, sistem dapat menandai artikel-artikel yang saat itu sedang «dibuka» guna menghindari konflik saat diedit.
  Opsi ini dinonaktifkan secara standar untuk menghindri pesan-pesan peringatan yang tidak perlu.',
	'texte_vide' => 'kosong',
	'texte_vider_cache' => 'Kosongkan cache',
	'titre_admin_tech' => 'Pemeliharaan teknis',
	'titre_admin_vider' => 'Pemeliharaan teknis',
	'titre_cadre_afficher_article' => 'Tampilkan artikel:',
	'titre_cadre_afficher_traductions' => 'Tampikan status terjemahan dari bahasa-bahasa berikut:',
	'titre_cadre_ajouter_auteur' => 'TAMBAH SEORANG PENULIS:',
	'titre_cadre_interieur_rubrique' => 'Dalam bagian',
	'titre_cadre_numero_auteur' => 'NOMOR PENULIS',
	'titre_cadre_signature_obligatoire' => '<b>Tanda tangan</b> [Dibutuhkan]<br />',
	'titre_config_fonctions' => 'Konfigurasi situs',
	'titre_configuration' => 'Konfigurasi situs',
	'titre_connexion_ldap' => 'Opsi: <b>Koneksi LDAP anda</b>',
	'titre_groupe_mots' => 'KELOMPOK KATA KUNCI:',
	'titre_langue_article' => 'BAHASA ARTIKEL', # MODIF
	'titre_langue_rubrique' => 'BAHASA BAGIAN', # MODIF
	'titre_langue_trad_article' => 'BAHASA ARTIKEL DAN TERJEMAHAN',
	'titre_les_articles' => 'ARTIKEL',
	'titre_naviguer_dans_le_site' => 'Jelajah situs...',
	'titre_nouvelle_rubrique' => 'Bagian baru',
	'titre_numero_rubrique' => 'NOMOR BAGIAN:',
	'titre_page_articles_edit' => 'Modifikasi: @titre@',
	'titre_page_articles_page' => 'Artikel',
	'titre_page_articles_tous' => 'Seluruh situs',
	'titre_page_calendrier' => 'Kalender @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Konfigurasi situs',
	'titre_page_delete_all' => 'penghapusan menyeluruh dan tidak dapat dikembalikan lagi',
	'titre_page_recherche' => 'Hasil pencarian @recherche@',
	'titre_page_statistiques_referers' => 'Statistik (tautan masuk)',
	'titre_page_upgrade' => 'Pembaharuan SPIP',
	'titre_publication_articles_post_dates' => 'Publikasi artikel terjadwal',
	'titre_reparation' => 'Perbaikan',
	'titre_suivi_petition' => 'Tindak lanjut petisi',
	'tls_ldap' => 'Pengamanan layer transportasi:',
	'trad_article_traduction' => 'Semua versi artikel ini:',
	'trad_delier' => 'Berhenti menautkan artikel ini ke terjemahannya', # MODIF
	'trad_lier' => 'Artikel ini adalah terjemahan dari artikel nomor:',
	'trad_new' => 'Tulis terjemahan baru untuk artikel ini', # MODIF

	// U
	'utf8_convert_erreur_orig' => 'Kesalahan: set karakter @charset@ tidak didukung.',

	// V
	'version' => 'Versi:'
);

?>
